@@ -4,12 +4,14 @@
 
 #include "benchmark/benchmark.h"
 
+namespace {
 // Tests that the user specified verbosity level can be get.
-static void BM_Verbosity(benchmark::State& state) {
+void BM_Verbosity(benchmark::State& state) {
   for (auto _ : state) {
   }
 }
 BENCHMARK(BM_Verbosity);
+}  // end namespace
 
 int main(int argc, char** argv) {
   benchmark::MaybeReenterWithoutASLR(argc, argv);
